@@ -111,6 +111,23 @@ class ffmpeg(devedeng.executor.executor):
 
         devedeng.executor.executor.__init__(self)
         self.config = devedeng.configuration_data.configuration.get_config()
+        try:
+            version_number = 0
+            handle = subprocess.Popen(
+                ["ffmpeg", "-version"], stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+            (stdout, stderr) = handle.communicate()
+            if 0 == handle.wait():
+                for line in stdout.decode("latin-1").split("\n"):
+                    line = line.strip()
+                    if line.startswith("ffmpeg version "):
+                        version_number = int(line[15:].split(".")[0])
+        except:
+            pass
+        print(version_number)
+        if version_number <= 6:
+            self._filter_sep = ",fifo,"
+        else:
+            self._filter_sep = ","
 
 
     def convert_file(self, file_project, output_file, video_length, pass2=False):
@@ -130,7 +147,7 @@ class ffmpeg(devedeng.executor.executor):
                 # add it as a child process of this one
                 self.add_child_process(tmp)
         else:
-            self.text = ("Converting %(X)s") % {"X": file_project.title_name}
+            self.text = _("Converting %(X)s") % {"X": file_project.title_name}
 
         if (pass2 == False) and (file_project.two_pass_encoding == True):
             # this is the first pass in a 2-pass codification
@@ -178,17 +195,31 @@ class ffmpeg(devedeng.executor.executor):
             vflip = False
             hflip = False
 
+            if (file_project.prerotation == 90):
+                if (cmd_line != ""):
+                    cmd_line += self._filter_sep
+                cmd_line += "transpose=1"
+            elif (file_project.prerotation == -90) or (file_project.prerotation == 270):
+                if (cmd_line != ""):
+                    cmd_line += self._filter_sep
+                cmd_line += "transpose=2"
+            elif (file_project.prerotation == 180):
+                if (cmd_line != ""):
+                    cmd_line += self._filter_sep
+                vflip = not vflip
+                hflip = not hflip
+
             if (file_project.rotation == "rotation_90"):
                 if (cmd_line != ""):
-                    cmd_line += ",fifo,"
+                    cmd_line += self._filter_sep
                 cmd_line += "transpose=1"
             elif (file_project.rotation == "rotation_270"):
                 if (cmd_line != ""):
-                    cmd_line += ",fifo,"
+                    cmd_line += self._filter_sep
                 cmd_line += "transpose=2"
             elif (file_project.rotation == "rotation_180"):
-                vflip = True
-                hflip = True
+                vflip = not vflip
+                hflip = not hflip
 
             if (file_project.mirror_vertical):
                 vflip = not vflip
@@ -197,30 +228,26 @@ class ffmpeg(devedeng.executor.executor):
 
             if (vflip):
                 if (cmd_line != ""):
-                    cmd_line += ",fifo,"
+                    cmd_line += self._filter_sep
                 cmd_line += "vflip"
             if (hflip):
                 if (cmd_line != ""):
-                    cmd_line += ",fifo,"
+                    cmd_line += self._filter_sep
                 cmd_line += "hflip"
 
             if (file_project.width_midle != file_project.original_width) or (file_project.height_midle != file_project.original_height):
                 if (cmd_line != ""):
-                    cmd_line += ",fifo,"
-                x = int((file_project.width_midle -
-                         file_project.original_width) / 2)
-                y = int((file_project.height_midle -
-                         file_project.original_height) / 2)
+                    cmd_line += self._filter_sep
+                x = int((file_project.width_midle - file_project.original_width) / 2)
+                y = int((file_project.height_midle - file_project.original_height) / 2)
                 if (x > 0) or (y > 0):
-                    cmd_line += "pad=" + str(file_project.width_midle) + ":" + str(
-                        file_project.height_midle) + ":" + str(x) + ":" + str(y) + ":0x000000"
+                    cmd_line += "pad=" + str(file_project.width_midle) + ":" + str(file_project.height_midle) + ":" + str(x) + ":" + str(y) + ":0x000000"
                 else:
-                    cmd_line += "crop=" + str(file_project.width_midle) + ":" + str(
-                        file_project.height_midle) + ":" + str(x) + ":" + str(y)
+                    cmd_line += "crop=" + str(file_project.width_midle) + ":" + str(file_project.height_midle) + ":" + str(x) + ":" + str(y)
 
             if (file_project.width_final != file_project.width_midle) or (file_project.height_final != file_project.height_midle):
                 if (cmd_line != ""):
-                    cmd_line += ",fifo,"
+                    cmd_line += self._filter_sep
                 cmd_line += "scale=" + \
                     str(file_project.width_final) + ":" + \
                     str(file_project.height_final)
@@ -493,6 +520,7 @@ class ffmpeg(devedeng.executor.executor):
                 self.command_var.append("1")
 
         self.command_var.append(output_file)
+        print(self.command_var)
 
     def _adjust_audio_bitrate(self, bitrate):
         br = [32, 48, 56, 64, 80, 96, 112, 128, 160, 192, 224, 256, 320, 384]
@@ -579,8 +607,11 @@ class ffmpeg(devedeng.executor.executor):
                 parts = data[0][pos:pos2].split(":")
                 t = 0.0
                 for e in parts:
-                    t *= 60.0
-                    t += float(e)
+                    try:
+                        v = float(e)
+                    except:
+                        continue
+                    t = t * 60.0 + v
                 t /= self.final_length
                 self.progress_bar[1].set_fraction(t)
                 self.progress_bar[1].set_text("%.1f%%" % (100.0 * t))
